@@ -76,7 +76,7 @@ fixed lengths.
 package Crypt::Ed25519;
 
 BEGIN {
-   $VERSION = 1.01;
+   $VERSION = 1.02;
 
    require XSLoader;
    XSLoader::load Crypt::Ed25519::, $VERSION;
@@ -188,6 +188,12 @@ private key is faster than using the secret key, so converting the secret
 key to a public/private key pair allows you to sign a small message, or
 many messages, faster.
 
+=head1 SUPPORT FOR THE PERL MULTICORE SPECIFICATION
+        
+This module supports the perl multicore specification
+(L<http://perlmulticore.schmorp.de/>) for key generation (usually the
+slowest operation), and all signing and verification functions.
+
 =head1 IMPLEMENTATIOIN
 
 This module currently uses "Nightcracker's Ed25519" implementation, which
